#
# spec file for package wp-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wp-cli
Version:        2.11.0
Release:        1.1
Summary:        WordPress command-line interface
License:        MIT
URL:            https://wp-cli.org/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.phar
Source1:        https://raw.githubusercontent.com/%{name}/%{name}/v%{version}/utils/wp-completion.bash
Requires:       php >= 5.6
Requires:       php-json
Requires:       php-openssl
Requires:       php-phar
Requires:       php-zip
BuildArch:      noarch

%description
WP-CLI is the command-line interface for WordPress. You can update plugins,
configure multisite installations and much more, without using a web browser.

%prep
%autosetup -c -T

%build

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{SOURCE0} %{buildroot}%{_bindir}/wp
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/profile.d

%check

%files
%defattr(-,root,root,0755)
%{_bindir}/wp
%config %{_sysconfdir}/profile.d/wp-completion.bash

%changelog
* Mon Feb 10 2025 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.11.0
  * Allow manually dispatching tests workflow [#5965]
  * Add fish shell completion [#5954]
  * Add defaults and accepted values for runcommand() options in doc [#5953]
  * Address warnings with filenames ending in fullstop on Windows [#5951]
  * Fix unit tests [#5950]
  * Update copyright year in license [#5942]
  * Fix breaking multi-line CSV values on reading [#5939]
  * Fix broken Gutenberg test [#5938]
  * Update docker runner to resolve docker path using /usr/bin/env [#5936]
  * Fix inherit path in nested directory [#5930]
  * Minor docblock improvements [#5929]
  * Add Signup fetcher [#5926]
  * Ensure the alias has the leading @ symbol when added [#5924]
  * Include any non default hook information in CompositeCommand [#5921]
  * Correct completion case when ends in = [#5913]
  * Docs: Fixes for inline comments [#5912]
  * Update Inline comments [#5910]
  * Add a real-world example for wp cli has-command [#5908]
  * Fix typos [#5901]
  * Avoid PHP deprecation notices in PHP 8.1.x [#5899]
* Sun Apr  7 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.10.0
  * Fix PHP deprecation warnings [#5897]
  * Only use --skip-column-statistics flag when available [#5895]
  * Handle unparseable tags gracefully [#5894]
  * WpOrgApi: allow specifying fields request param [#5893]
  * Remove unneeded compatibility shim [#5885]
  * Suggest 'network meta' intead of 'network option' [#5879]
  * Updated Doc Block for Admin.php [#5877]
  * Admin Context: Fix PHP fatals when admin.php has CRLF line endings [#5875]
  * Standard completion of current option [#5873]
  * Add WP_CLI\Utils\has_stdin() function [#5872]
  * Add verbosity level and quiet flag in ssh command based on debug flag [#5869]
  * Revert "Move RecursiveDataStructureTraverser to wp-cli/wp-cli package" [#5866]
  * Add missing required arguments when using --prompt [#5865]
  * Move RecursiveDataStructureTraverser to wp-cli/wp-cli package [#5864]
  * Add docker compose command support in SSH command generation [#5863]
  * Add missing documentation for $data attribute in http_request() [#5861]
  * Updated Inline PHP Documentation [#5853]
- Update to version 2.9.0
  * Add debugging output for @when command registration [#5841]
  * Fix --skip-themes for WordPress 6.4 [#5840]
  * Update phpcs.xml to match new WPCS rules [#5836]
  * Update to WPCS v3 [#5834]
  * Respect alias --path= in IncludeRequestsAutoloader [#5830]
  * Update type hint of $callable parameter in add_command() method [#5828]
  * Display a custom error message when themes/functions.php fatals [#5817]
  * Fix PHP 8.1 deprecation: ReturnTypeWillChange [#5807]
  * Add support for the proxyjump key [#5805]
  * Mention updating the homepage in the release process [#5802]
* Mon Jun 26 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.8.1
  * Define WP_CLI_ROOT if needed
  * Extract Requests out of Composer
- Update to version 2.8.0
  * Ignore Requests deprecations in error handling for now
  * Fallback to hardcoded folder when WPINC not defined
  * Conditionally adapt to Core Requests library
  * Add bootstrap step to extract default CA certificate
  * Use wp_cache_flush_runtime if supported.
  * Extract cacert from Phar for cURL
  * Fix some PHP 8.2 depreciation notices in behat tests
  * Upgrade WP-CLI to Requests v2
  * Added "wp cli alias is-group" subcommand.
  * Use -R instead of -r for fallback pager command
  * Fix autocompletion notice with PHP 8.2
  * fix PHP Deprecation for 8.1
  * Add composer phpcbf
  * Use WP_CLI_FORCE_USER_LOGIN=1 to force --user=<login>
  * Fix --skip-themes for themes with block patterns
  * Fix deprecation notice triggered in WpOrgApi class in PHP 8.1
  * Improve support for cases with empty --path provided to wp-cli commands
  * PHP 8.2: explicitly declare CompositeCommand::$longdesc to fix deprecation warning
  * Detect Object Cache Pro
  * Ensure WP_CLI_ROOT is defined before accessing it
* Tue Nov  8 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.7.1
  * Avoid deleting TinyMCE themes/plugins by using more precise check
  * Support for docker-compose run
  * Customizable global parameters
  * Download WordPress Core files without extracting them
  * Directly install a specific locale
  * Clean duplicate meta values
  * Multiple changes to the i18n support
  * PHP 8.1 Support
  * New commands for managing application passwords
  * New global flag: --context
  * Configurable WP-CLI cache settings
  * Use custom names/locations for the wp-config.php file
  * Generate a dotenv file from your existing wp-config.php file
  * Allow plugin/theme enumeration without forcing an update check
  * New flag --strict for adapting the filtering of taxonomies by post type
* Sat Jul 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.5.0
  * Fix CVE-2021-29504: An improper error handling in HTTPS requests
    management in WP-CLI since version 0.12.0, allowing remote
    attackers able to intercept the communication to remotely disable
    the certificate verification on WP-CLI side
  * The security fix might break systems with invalid certificates,
    for old behavior "--insecure" flag was added
  * PHP 8 support
  * Improved MySQL/MariaDB support
  * Package Manager is now powered by Composer v2, speed improvements
  * New commands for managing automatic updates
  * New command for creating MO files
  * New environment variable: WP_CLI_ALLOW_ROOT
  * Support for third-party WP-CLI packages on GitLab
  * Full release notes:
    https://make.wordpress.org/cli/2021/05/19/wp-cli-v2-5-0-release-notes
* Mon Jan 13 2020 Matthias Fehring <buschmann23@opensuse.org>
- Version 2.4.0
  * Release notes: https://make.wordpress.org/cli/2019/11/12/wp-cli-v2-4-0-release-notes/
* Sun Nov  3 2019 Yunhe Guo <i@guoyunhe.me>
- Correct the URL of bash completion file
* Sun Nov  3 2019 Yunhe Guo <i@guoyunhe.me>
- Version 2.3.0
  * Release notes: https://make.wordpress.org/cli/2019/08/14/wp-cli-release-v2-3-0/
